==> qtbase-6.10.1-1.gpkg.tar: image/usr/include/qt6/QtGui/6.10.1/QtGui/private/qtgui-config_p.h <==
#ifndef QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
#define QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H

#define QT_FEATURE_accessibility_atspi_bridge 1

#define QT_FEATURE_directfb -1

#define QT_FEATURE_directwrite -1

#define QT_FEATURE_directwrite3 -1

#define QT_FEATURE_directwritecolrv1 -1

#define QT_FEATURE_direct2d -1

#define QT_FEATURE_direct2d1_1 -1

#define QT_FEATURE_emojisegmenter 1

#define QT_FEATURE_evdev -1

#define QT_FEATURE_vxworksevdev -1

#define QT_FEATURE_freetype 1

#define QT_FEATURE_system_freetype 1

#define QT_FEATURE_fontconfig 1

#define QT_FEATURE_harfbuzz 1

#define QT_FEATURE_system_harfbuzz 1

#define QT_FEATURE_qqnx_imf -1

#define QT_FEATURE_integrityfb -1

#define QT_FEATURE_kms 1

#define QT_FEATURE_drm_atomic 1

#define QT_FEATURE_libinput 1

#define QT_FEATURE_integrityhid -1

#define QT_FEATURE_libinput_axis_api 1

#define QT_FEATURE_libinput_hires_wheel_support 1

#define QT_FEATURE_linuxfb 1

#define QT_FEATURE_vsp2 -1

#define QT_FEATURE_vnc 1

#define QT_FEATURE_mtdev -1

#define QT_FEATURE_vkgen 1

#define QT_FEATURE_vkkhrdisplay 1

#define QT_FEATURE_egl_x11 1

#define QT_FEATURE_eglfs -1

#define QT_FEATURE_eglfs_brcm -1

#define QT_FEATURE_eglfs_egldevice -1

#define QT_FEATURE_eglfs_gbm -1

#define QT_FEATURE_eglfs_vsp2 -1

#define QT_FEATURE_eglfs_mali -1

#define QT_FEATURE_eglfs_viv -1

#define QT_FEATURE_eglfs_rcar -1

#define QT_FEATURE_eglfs_viv_wl -1

#define QT_FEATURE_eglfs_openwfd -1

#define QT_FEATURE_eglfs_x11 -1

#define QT_FEATURE_gif 1

#define QT_FEATURE_ico 1

#define QT_FEATURE_jpeg 1

#define QT_FEATURE_system_jpeg 1

#define QT_FEATURE_png 1

#define QT_FEATURE_system_png 1

#define QT_FEATURE_imageio_text_loading 1

#define QT_FEATURE_tslib -1

#define QT_FEATURE_tuiotouch 1

#define QT_FEATURE_xcb_glx 1

#define QT_FEATURE_xcb_egl_plugin 1

#define QT_FEATURE_xcb_native_painting -1

#define QT_FEATURE_xrender -1

#define QT_FEATURE_xcb_xlib 1

#define QT_FEATURE_xcb_sm 1

#define QT_FEATURE_system_xcb_xinput 1

#define QT_FEATURE_xkbcommon 1

#define QT_FEATURE_xkbcommon_x11 1

#define QT_FEATURE_xlib 1

#define QT_FEATURE_multiprocess 1

#define QT_FEATURE_raster_64bit 1

#define QT_FEATURE_raster_fp 1

#define QT_FEATURE_qtgui_threadpool 1

#define QT_FEATURE_graphicsframecapture -1

#define QT_FEATURE_wayland_client 1

#define QT_FEATURE_wayland_server 1

#define QT_FEATURE_wayland_egl 1

#define QT_FEATURE_wayland_brcm -1

#define QT_FEATURE_wayland_drm_egl_server_buffer 1

#define QT_FEATURE_wayland_libhybris_egl_server_buffer -1

#define QT_FEATURE_wayland_dmabuf_server_buffer 1

#define QT_FEATURE_wayland_shm_emulation_server_buffer 1

#define QT_FEATURE_wayland_vulkan_server_buffer 1

#define QT_FEATURE_wayland_datadevice 1

#define QT_FEATURE_wayland_client_primary_selection 1

#define QT_FEATURE_wayland_client_fullscreen_shell_v1 1

#define QT_FEATURE_wayland_client_wl_shell 1

#define QT_FEATURE_wayland_client_xdg_shell 1

#define QT_FEATURE_egl_extension_platform_wayland 1

#define QT_FEATURE_run_opengl_tests 1


#endif // QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H

==> qtbase-6.10.2.gpkg.tar: image/usr/include/qt6/QtGui/6.10.2/QtGui/private/qtgui-config_p.h <==
#ifndef QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
#define QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H

#define QT_FEATURE_accessibility_atspi_bridge 1

#define QT_FEATURE_directfb -1

#define QT_FEATURE_directwrite -1

#define QT_FEATURE_directwrite3 -1

#define QT_FEATURE_directwritecolrv1 -1

#define QT_FEATURE_direct2d -1

#define QT_FEATURE_direct2d1_1 -1

#define QT_FEATURE_emojisegmenter 1

#define QT_FEATURE_evdev 1

#define QT_FEATURE_vxworksevdev -1

#define QT_FEATURE_freetype 1

#define QT_FEATURE_system_freetype 1

#define QT_FEATURE_fontconfig 1

#define QT_FEATURE_harfbuzz 1

#define QT_FEATURE_system_harfbuzz 1

#define QT_FEATURE_qqnx_imf -1

#define QT_FEATURE_integrityfb -1

#define QT_FEATURE_kms 1

#define QT_FEATURE_drm_atomic 1

#define QT_FEATURE_libinput 1

#define QT_FEATURE_integrityhid -1

#define QT_FEATURE_libinput_axis_api 1

#define QT_FEATURE_libinput_hires_wheel_support 1

#define QT_FEATURE_linuxfb 1

#define QT_FEATURE_vsp2 -1

#define QT_FEATURE_vnc 1

#define QT_FEATURE_mtdev 1

#define QT_FEATURE_vkgen 1

#define QT_FEATURE_vkkhrdisplay 1

#define QT_FEATURE_egl_x11 1

#define QT_FEATURE_eglfs -1

#define QT_FEATURE_eglfs_brcm -1

#define QT_FEATURE_eglfs_egldevice -1

#define QT_FEATURE_eglfs_gbm -1

#define QT_FEATURE_eglfs_vsp2 -1

#define QT_FEATURE_eglfs_mali -1

#define QT_FEATURE_eglfs_viv -1

#define QT_FEATURE_eglfs_rcar -1

#define QT_FEATURE_eglfs_viv_wl -1

#define QT_FEATURE_eglfs_openwfd -1

#define QT_FEATURE_eglfs_x11 -1

#define QT_FEATURE_gif 1

#define QT_FEATURE_ico 1

#define QT_FEATURE_jpeg 1

#define QT_FEATURE_system_jpeg 1

#define QT_FEATURE_png 1

#define QT_FEATURE_system_png 1

#define QT_FEATURE_imageio_text_loading 1

#define QT_FEATURE_tslib -1

#define QT_FEATURE_tuiotouch 1

#define QT_FEATURE_xcb_glx 1

#define QT_FEATURE_xcb_egl_plugin 1

#define QT_FEATURE_xcb_native_painting -1

#define QT_FEATURE_xrender -1

#define QT_FEATURE_xcb_xlib 1

#define QT_FEATURE_xcb_sm 1

#define QT_FEATURE_system_xcb_xinput 1

#define QT_FEATURE_xkbcommon 1

#define QT_FEATURE_xkbcommon_x11 1

#define QT_FEATURE_xlib 1

#define QT_FEATURE_multiprocess 1

#define QT_FEATURE_raster_64bit 1

#define QT_FEATURE_raster_fp 1

#define QT_FEATURE_qtgui_threadpool 1

#define QT_FEATURE_graphicsframecapture -1

#define QT_FEATURE_wayland_client 1

#define QT_FEATURE_wayland_server 1

#define QT_FEATURE_wayland_egl 1

#define QT_FEATURE_wayland_brcm -1

#define QT_FEATURE_wayland_drm_egl_server_buffer 1

#define QT_FEATURE_wayland_libhybris_egl_server_buffer -1

#define QT_FEATURE_wayland_dmabuf_server_buffer 1

#define QT_FEATURE_wayland_shm_emulation_server_buffer 1

#define QT_FEATURE_wayland_vulkan_server_buffer 1

#define QT_FEATURE_wayland_datadevice 1

#define QT_FEATURE_wayland_client_primary_selection 1

#define QT_FEATURE_wayland_client_fullscreen_shell_v1 1

#define QT_FEATURE_wayland_client_wl_shell 1

#define QT_FEATURE_wayland_client_xdg_shell 1

#define QT_FEATURE_egl_extension_platform_wayland 1

#define QT_FEATURE_run_opengl_tests 1


#endif // QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
